@@ -1,7 +1,9 @@
-from typing import Optional, Sequence, Type
+from collections.abc import Sequence
+from typing import Optional
 
 import pandas as pd
 from dagster import InputContext, MetadataValue, OutputContext, TableColumn, TableSchema
+from dagster._core.definitions.metadata import TableMetadataSet
 from dagster._core.storage.db_io_manager import DbTypeHandler, TableSlice
 from dagster_gcp.bigquery.io_manager import (
     BigQueryClient,
@@ -57,7 +59,13 @@ class BigQueryPandasTypeHandler(DbTypeHandler[pd.DataFrame]):
 
         context.add_output_metadata(
             {
-                "row_count": obj.shape[0],
+                # output object may be a slice/partition, so we output different metadata keys based on
+                # whether this output represents an entire table or just a slice/partition
+                **(
+                    TableMetadataSet(partition_row_count=obj.shape[0])
+                    if context.has_partition_key
+                    else TableMetadataSet(row_count=obj.shape[0])
+                ),
                 "dataframe_columns": MetadataValue.table_schema(
                     TableSchema(
                         columns=[
@@ -289,5 +297,5 @@ class BigQueryPandasIOManager(BigQueryIOManager):
         return [BigQueryPandasTypeHandler()]
 
     @staticmethod
-    def default_load_type() -> Optional[Type]:
+    def default_load_type() -> Optional[type]:
         return pd.DataFrame
